;/**
; *******************************************************************************
; * @file    startup_TMPM383.s
; * @brief   CMSIS Cortex-M3 Core Device Startup File for the
; *          TOSHIBA 'TMPM383' Device Series
; * @version V2.0.2.3
; * @date    2016/07/11
; *------- <<< Use Configuration Wizard in Context Menu >>> ------------------
; * 
; * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
; * 
; * (C)Copyright TOSHIBA ELECTRONIC DEVICES & STORAGE CORPORATION 2017 All rights reserved
; *******************************************************************************
; */

; <h> Stack Configuration
;   <o> Stack Size (in Bytes) <0x0-0xFFFFFFFF:8>
; </h>

Stack_Size      EQU     0x00000200

                AREA    STACK, NOINIT, READWRITE, ALIGN=3
Stack_Mem       SPACE   Stack_Size
__initial_sp


; <h> Heap Configuration
;   <o>  Heap Size (in Bytes) <0x0-0xFFFFFFFF:8>
; </h>

Heap_Size       EQU     0x00000000

                AREA    HEAP, NOINIT, READWRITE, ALIGN=3
__heap_base
Heap_Mem        SPACE   Heap_Size
__heap_limit


                PRESERVE8
                THUMB


; Vector Table Mapped to Address 0 at Reset

                AREA    RESET, DATA, READONLY
                EXPORT  __Vectors

__Vectors       DCD     __initial_sp              ; Top of Stack
                DCD     Reset_Handler             ; Reset Handler
                DCD     NMI_Handler               ; NMI Handler
                DCD     HardFault_Handler         ; Hard Fault Handler
                DCD     MemManage_Handler         ; MPU Fault Handler
                DCD     BusFault_Handler          ; Bus Fault Handler
                DCD     UsageFault_Handler        ; Usage Fault Handler
                DCD     0                         ; Reserved
                DCD     0                         ; Reserved
                DCD     0                         ; Reserved
                DCD     0                         ; Reserved
                DCD     SVC_Handler               ; SVCall Handler
                DCD     DebugMon_Handler          ; Debug Monitor Handler
                DCD     0                         ; Reserved
                DCD     PendSV_Handler            ; PendSV Handler
                DCD     SysTick_Handler           ; SysTick Handler

                ; External Interrupts
                DCD     INT0_IRQHandler           ; 0:	Interrupt pin (PH0/AIN0/INT0)
                DCD     INT1_IRQHandler           ; 1:	Interrupt pin (PH1/AIN1/INT1)
                DCD     INT2_IRQHandler           ; 2:	Interrupt pin (PH2/AIN2/INT2)
                DCD     INT3_IRQHandler           ; 3:	Interrupt pin (PA0/TB0IN/INT3)
                DCD     INT4_IRQHandler           ; 4:	Interrupt pin (PA2/TB1IN/INT4)
                DCD     INT5_IRQHandler           ; 5:	Interrupt pin (PE4/TB2IN/INT5)
                DCD     INTRX0_IRQHandler         ; 6:	Serial reception (channel.0)
                DCD     INTTX0_IRQHandler         ; 7:	Serial transmission (channel.0)
                DCD     INTRX1_IRQHandler         ; 8:	Serial reception (channel.1)
                DCD     INTTX1_IRQHandler         ; 9:	Serial transmission (channel.1)
                DCD     INTSSP0_IRQHandler        ; 10:	Syncronous Serial Port 0
                DCD     0                         ; 11:	Reserved
                DCD     0                         ; 12:	Reserved
                DCD     0                         ; 13:	Reserved
                DCD     INTSBI0_IRQHandler        ; 14:	Serial Bus Interface 0 interrupt
                DCD     0                         ; 15:	Reserved
                DCD     0                         ; 16:	Reserved
                DCD     INTRTC_IRQHandler         ; 17:	Realtime clock interrupt
                DCD     0                         ; 18:	Reserved
                DCD     INTRMCRX_IRQHandler       ; 19:	Remote Controller reception interrupt
                DCD     INTTB00_IRQHandler        ; 20:	16bit TMRB0 compare match detection 0
                DCD     INTTB01_IRQHandler        ; 21:	16bit TMRB0 compare match detection 1
                DCD     INTTB10_IRQHandler        ; 22:	16bit TMRB1 compare match detection 0
                DCD     INTTB11_IRQHandler        ; 23:	16bit TMRB1 compare match detection 1
                DCD     INTTB40_IRQHandler        ; 24:	16bit TMRB4 compare match detection 0
                DCD     INTTB41_IRQHandler        ; 25:	16bit TMRB4 compare match detection 1
                DCD     INTTB50_IRQHandler        ; 26:	16bit TMRB5 compare match detection 0
                DCD     INTTB51_IRQHandler        ; 27:	16bit TMRB5 compare match detection 1
                DCD     0                         ; 28:	Reserved
                DCD     0                         ; 29:	Reserved
                DCD     INTCAP00_IRQHandler       ; 30:	16bit TMRB0 input capture 0
                DCD     INTCAP01_IRQHandler       ; 31:	16bit TMRB0 input capture 1
                DCD     INTCAP10_IRQHandler       ; 32:	16bit TMRB1 input capture 0
                DCD     INTCAP11_IRQHandler       ; 33:	16bit TMRB1 input capture 1
                DCD     INTCAP40_IRQHandler       ; 34:	16bit TMRB4 input capture 0
                DCD     INTCAP41_IRQHandler       ; 35:	16bit TMRB4 input capture 1
                DCD     INTCAP50_IRQHandler       ; 36:	16bit TMRB5 input capture 0
                DCD     INTCAP51_IRQHandler       ; 37:	16bit TMRB5 input capture 1
                DCD     0                         ; 38:	Reserved
                DCD     0                         ; 39:	Reserved
                DCD     0                         ; 40:	Reserved
                DCD     0                         ; 41:	Reserved
                DCD     INTADCP0_IRQHandler       ; 42:	ADC conversion monitoring function interrupt 0
                DCD     INTADCP1_IRQHandler       ; 43:	ADC conversion monitoring function interrupt 1
                DCD     INTUART0_IRQHandler       ; 44:	UART transmission and reception interrupt (channel.0)
                DCD     0                         ; 45:	Reserved
                DCD     INTTB20_IRQHandler        ; 46:	16bit TMRB2 compare match detection 0
                DCD     INTTB21_IRQHandler        ; 47:	16bit TMRB2 compare match detection 1
                DCD     INTTB30_IRQHandler        ; 48:	16bit TMRB3 compare match detection 0
                DCD     INTTB31_IRQHandler        ; 49:	16bit TMRB3 compare match detection 1
                DCD     INTCAP20_IRQHandler       ; 50:	16bit TMRB2 input capture 0
                DCD     INTCAP21_IRQHandler       ; 51:	16bit TMRB2 input capture 1
                DCD     INTCAP30_IRQHandler       ; 52:	16bit TMRB3 input capture 0
                DCD     INTCAP31_IRQHandler       ; 53:	16bit TMRB3 input capture 1
                DCD     INTADSFT_IRQHandler       ; 54:	ADC conversion started by software is finished
                DCD     0                         ; 55:	Reserved
                DCD     INTADTMR_IRQHandler       ; 56:	ADC conversion triggered by timer is finished
                DCD     0                         ; 57:	Reserved
                DCD     INT8_IRQHandler           ; 58:	Interrupt Pin (PA7/TB4IN/INT8)
                DCD     0                         ; 59:	Reserved
                DCD     0                         ; 60:	Reserved
                DCD     0                         ; 61:	Reserved
                DCD     0                         ; 62:	Reserved
                DCD     0                         ; 63:	Reserved
                DCD     0                         ; 64:	Reserved
                DCD     0                         ; 65:	Reserved
                DCD     INTTB60_IRQHandler        ; 66:	16bit TMRB6 compare match detection 0
                DCD     INTTB61_IRQHandler        ; 67:	16bit TMRB6 compare match detection 1
                DCD     INTTB70_IRQHandler        ; 68:	16bit TMRB7 compare match detection 0
                DCD     INTTB71_IRQHandler        ; 69:	16bit TMRB7 compare match detection 1
                DCD     INTCAP60_IRQHandler       ; 70:	16bit TMRB6 input capture 0
                DCD     INTCAP61_IRQHandler       ; 71:	16bit TMRB6 input capture 1
                DCD     INTCAP70_IRQHandler       ; 72:	16bit TMRB7 input capture 0
                DCD     INTCAP71_IRQHandler       ; 73:	16bit TMRB7 input capture 1
                DCD     0                         ; 74:	Reserved
                DCD     0                         ; 75:	Reserved
                DCD     0                         ; 76:	Reserved
                DCD     INTF_IRQHandler           ; 77:	Interrupt Pin (PL2/INTF)



                AREA    |.text|, CODE, READONLY


; Reset Handler

Reset_Handler   PROC
                EXPORT  Reset_Handler             [WEAK]
                IMPORT  SystemInit
                IMPORT  __main
                LDR     R0, =SystemInit
                BLX     R0
                LDR     R0, =__main
                BX      R0
                ENDP


; Dummy Exception Handlers (infinite loops which can be modified)

NMI_Handler     PROC
                EXPORT  NMI_Handler               [WEAK]
                B       .
                ENDP
HardFault_Handler\
                PROC
                EXPORT  HardFault_Handler         [WEAK]
                B       .
                ENDP
MemManage_Handler\
                PROC
                EXPORT  MemManage_Handler         [WEAK]
                B       .
                ENDP
BusFault_Handler\
                PROC
                EXPORT  BusFault_Handler          [WEAK]
                B       .
                ENDP
UsageFault_Handler\
                PROC
                EXPORT  UsageFault_Handler        [WEAK]
                B       .
                ENDP
SVC_Handler     PROC
                EXPORT  SVC_Handler               [WEAK]
                B       .
                ENDP
DebugMon_Handler\
                PROC
                EXPORT  DebugMon_Handler          [WEAK]
                B       .
                ENDP
PendSV_Handler  PROC
                EXPORT  PendSV_Handler            [WEAK]
                B       .
                ENDP
SysTick_Handler PROC
                EXPORT  SysTick_Handler           [WEAK]
                B       .
                ENDP

Default_Handler PROC

                EXPORT  INT0_IRQHandler           [WEAK]
                EXPORT  INT1_IRQHandler           [WEAK]
                EXPORT  INT2_IRQHandler           [WEAK]
                EXPORT  INT3_IRQHandler           [WEAK]
                EXPORT  INT4_IRQHandler           [WEAK]
                EXPORT  INT5_IRQHandler           [WEAK]
                EXPORT  INTRX0_IRQHandler         [WEAK]
                EXPORT  INTTX0_IRQHandler         [WEAK]
                EXPORT  INTRX1_IRQHandler         [WEAK]
                EXPORT  INTTX1_IRQHandler         [WEAK]
                EXPORT  INTSSP0_IRQHandler        [WEAK]
                EXPORT  INTSBI0_IRQHandler        [WEAK]
                EXPORT  INTRTC_IRQHandler         [WEAK]
                EXPORT  INTRMCRX_IRQHandler       [WEAK]
                EXPORT  INTTB00_IRQHandler        [WEAK]
                EXPORT  INTTB01_IRQHandler        [WEAK]
                EXPORT  INTTB10_IRQHandler        [WEAK]
                EXPORT  INTTB11_IRQHandler        [WEAK]
                EXPORT  INTTB40_IRQHandler        [WEAK]
                EXPORT  INTTB41_IRQHandler        [WEAK]
                EXPORT  INTTB50_IRQHandler        [WEAK]
                EXPORT  INTTB51_IRQHandler        [WEAK]
                EXPORT  INTCAP00_IRQHandler       [WEAK]
                EXPORT  INTCAP01_IRQHandler       [WEAK]
                EXPORT  INTCAP10_IRQHandler       [WEAK]
                EXPORT  INTCAP11_IRQHandler       [WEAK]
                EXPORT  INTCAP40_IRQHandler       [WEAK]
                EXPORT  INTCAP41_IRQHandler       [WEAK]
                EXPORT  INTCAP50_IRQHandler       [WEAK]
                EXPORT  INTCAP51_IRQHandler       [WEAK]
                EXPORT  INTADCP0_IRQHandler       [WEAK]
                EXPORT  INTADCP1_IRQHandler       [WEAK]
                EXPORT  INTUART0_IRQHandler       [WEAK]
                EXPORT  INTTB20_IRQHandler        [WEAK]
                EXPORT  INTTB21_IRQHandler        [WEAK]
                EXPORT  INTTB30_IRQHandler        [WEAK]
                EXPORT  INTTB31_IRQHandler        [WEAK]
                EXPORT  INTCAP20_IRQHandler       [WEAK]
                EXPORT  INTCAP21_IRQHandler       [WEAK]
                EXPORT  INTCAP30_IRQHandler       [WEAK]
                EXPORT  INTCAP31_IRQHandler       [WEAK]
                EXPORT  INTADSFT_IRQHandler       [WEAK]
                EXPORT  INTADTMR_IRQHandler       [WEAK]
                EXPORT  INT8_IRQHandler           [WEAK]
                EXPORT  INTTB60_IRQHandler        [WEAK]
                EXPORT  INTTB61_IRQHandler        [WEAK]
                EXPORT  INTTB70_IRQHandler        [WEAK]
                EXPORT  INTTB71_IRQHandler        [WEAK]
                EXPORT  INTCAP60_IRQHandler       [WEAK]
                EXPORT  INTCAP61_IRQHandler       [WEAK]
                EXPORT  INTCAP70_IRQHandler       [WEAK]
                EXPORT  INTCAP71_IRQHandler       [WEAK]
                EXPORT  INTF_IRQHandler           [WEAK]

INT0_IRQHandler
INT1_IRQHandler
INT2_IRQHandler
INT3_IRQHandler
INT4_IRQHandler
INT5_IRQHandler
INTRX0_IRQHandler
INTTX0_IRQHandler
INTRX1_IRQHandler
INTTX1_IRQHandler
INTSSP0_IRQHandler
INTSBI0_IRQHandler
INTRTC_IRQHandler
INTRMCRX_IRQHandler
INTTB00_IRQHandler
INTTB01_IRQHandler
INTTB10_IRQHandler
INTTB11_IRQHandler
INTTB40_IRQHandler
INTTB41_IRQHandler
INTTB50_IRQHandler
INTTB51_IRQHandler
INTCAP00_IRQHandler
INTCAP01_IRQHandler
INTCAP10_IRQHandler
INTCAP11_IRQHandler
INTCAP40_IRQHandler
INTCAP41_IRQHandler
INTCAP50_IRQHandler
INTCAP51_IRQHandler
INTADCP0_IRQHandler
INTADCP1_IRQHandler
INTUART0_IRQHandler
INTTB20_IRQHandler
INTTB21_IRQHandler
INTTB30_IRQHandler
INTTB31_IRQHandler
INTCAP20_IRQHandler
INTCAP21_IRQHandler
INTCAP30_IRQHandler
INTCAP31_IRQHandler
INTADSFT_IRQHandler
INTADTMR_IRQHandler
INT8_IRQHandler
INTTB60_IRQHandler
INTTB61_IRQHandler
INTTB70_IRQHandler
INTTB71_IRQHandler
INTCAP60_IRQHandler
INTCAP61_IRQHandler
INTCAP70_IRQHandler
INTCAP71_IRQHandler
INTF_IRQHandler

                B       .

                ENDP


                ALIGN


; User Initial Stack & Heap

                IF      :DEF:__MICROLIB

                EXPORT  __initial_sp
                EXPORT  __heap_base
                EXPORT  __heap_limit

                ELSE

                IMPORT  __use_two_region_memory
                EXPORT  __user_initial_stackheap
__user_initial_stackheap

                LDR     R0, =  Heap_Mem
                LDR     R1, =(Stack_Mem + Stack_Size)
                LDR     R2, = (Heap_Mem +  Heap_Size)
                LDR     R3, = Stack_Mem
                BX      LR

                ALIGN

                ENDIF


                END

