/** 
 *******************************************************************************
 * @file    tmpm383_fuart.h
 * @brief   This file provides all the functions prototypes for Full UART driver.
 * @version V2.0.2.1
 * @date    2015/06/01
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * (C)Copyright TOSHIBA ELECTRONIC DEVICES & STORAGE CORPORATION 2017 All rights reserved
 *******************************************************************************
 */

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef __TMPM383_FUART_H
#define __TMPM383_FUART_H

#ifdef __cplusplus
extern "C" {
#endif

/* Includes ------------------------------------------------------------------*/
#include "TMPM383.h"
#include "tx03_common.h"

#if defined(__TMPM383_FUART_H)
/** @addtogroup TX03_Periph_Driver
  * @{
  */

/** @addtogroup FUART
  * @{
  */

/** @defgroup FUART_Exported_Types
  * @{
  */

/** 
  * @brief  FUART Init Structure definition
  */

    typedef struct {
        uint32_t BaudRate;      /*!< This member configures the Full UART communication
                                   baud rate. */
        uint32_t DataBits;      /*!< Specifies FUART transfer mode, which could be 
                                   5-bit mode, 6-bit mode, 7-bit mode or 8-bit mode. */
        uint32_t StopBits;      /*!< Specifies the length of stop bit transmission
                                   in Full UART. */
        uint32_t Parity;        /*!< Specifies the parity mode which could be  0 parity,
                                   1 parity, odd parity, even parity or no parity. */
        uint32_t Mode;          /*!< Enables or disables Receive, Transmit or 
                                   both. */
        uint32_t FlowCtrl;      /*!< Specifies the hardware flow control mode, which can be
                                   CTS flow control, RTS flow control or none flow control. */
    } FUART_InitTypeDef;

/** @} */
/* End of group FUART_Exported_Types */

/** @defgroup FUART_Exported_Constants
  * @{
  */
#define FUART0                                 TSB_UART0

#define IS_FUART_PERIPH(param)                 ((param) == FUART0)

#define IS_FUART_BAUDRATE(param)               (((param) != 0U) && \
                                                ((param) <= 6250000U))

#define FUART_DATA_BITS_5                      ((uint32_t)0x00000000)
#define FUART_DATA_BITS_6                      ((uint32_t)0x00000020)
#define FUART_DATA_BITS_7                      ((uint32_t)0x00000040)
#define FUART_DATA_BITS_8                      ((uint32_t)0x00000060)

#define IS_FUART_DATA_BITS(param)              (((param) == FUART_DATA_BITS_5) || \
                                                ((param) == FUART_DATA_BITS_6) || \
                                                ((param) == FUART_DATA_BITS_7) || \
                                                ((param) == FUART_DATA_BITS_8))

#define FUART_STOP_BITS_1                      ((uint32_t)0x00000000)
#define FUART_STOP_BITS_2                      ((uint32_t)0x00000008)
#define IS_FUART_STOPBITS(param)               (((param) == FUART_STOP_BITS_1) || \
                                                ((param) == FUART_STOP_BITS_2))

#define FUART_NO_PARITY                        ((uint32_t)0x00000000)
#define FUART_0_PARITY                         ((uint32_t)0x00000086)
#define FUART_1_PARITY                         ((uint32_t)0x00000082)
#define FUART_EVEN_PARITY                      ((uint32_t)0x00000006)
#define FUART_ODD_PARITY                       ((uint32_t)0x00000002)
#define IS_FUART_PARITY(param)                 (((param) == FUART_NO_PARITY) || \
                                                ((param) == FUART_0_PARITY) || \
                                                ((param) == FUART_1_PARITY) || \
                                                ((param) == FUART_EVEN_PARITY) || \
                                                ((param) == FUART_ODD_PARITY))

#define FUART_ENABLE_RX                         ((uint32_t)0x00000200)
#define FUART_ENABLE_TX                         ((uint32_t)0x00000100)
#define IS_FUART_MODE(param)                    (((param) == FUART_ENABLE_RX) || \
                                                 ((param) == FUART_ENABLE_TX) || \
                                                 ((param) == (FUART_ENABLE_TX | FUART_ENABLE_RX)))

#define FUART_NONE_FLOW_CTRL                   ((uint32_t)0x00000000)
#define IS_FUART_FLOW_CTRL(param)              ((param) == FUART_NONE_FLOW_CTRL)

#define FUART_RX_FIFO_LEVEL_4                  ((uint32_t)0x00000000)
#define FUART_RX_FIFO_LEVEL_8                  ((uint32_t)0x00000008)
#define FUART_RX_FIFO_LEVEL_16                 ((uint32_t)0x00000010)
#define FUART_RX_FIFO_LEVEL_24                 ((uint32_t)0x00000018)
#define FUART_RX_FIFO_LEVEL_28                 ((uint32_t)0x00000020)

#define IS_FUART_RX_FIFO_LEVEL(param)          (((param) == FUART_RX_FIFO_LEVEL_4) || \
                                                ((param) == FUART_RX_FIFO_LEVEL_8) || \
                                                ((param) == FUART_RX_FIFO_LEVEL_16) || \
                                                ((param) == FUART_RX_FIFO_LEVEL_24) || \
                                                ((param) == FUART_RX_FIFO_LEVEL_28))

#define FUART_TX_FIFO_LEVEL_4                  ((uint32_t)0x00000000)
#define FUART_TX_FIFO_LEVEL_8                  ((uint32_t)0x00000001)
#define FUART_TX_FIFO_LEVEL_16                 ((uint32_t)0x00000002)
#define FUART_TX_FIFO_LEVEL_24                 ((uint32_t)0x00000003)
#define FUART_TX_FIFO_LEVEL_28                 ((uint32_t)0x00000004)

#define IS_FUART_TX_FIFO_LEVEL(param)          (((param) == FUART_TX_FIFO_LEVEL_4) || \
                                                ((param) == FUART_TX_FIFO_LEVEL_8) || \
                                                ((param) == FUART_TX_FIFO_LEVEL_16) || \
                                                ((param) == FUART_TX_FIFO_LEVEL_24) || \
                                                ((param) == FUART_TX_FIFO_LEVEL_28))

#define FUART_NONE_INT_MASK                    ((uint32_t)0x00000000)
#define FUART_RX_FIFO_INT_MASK                 ((uint32_t)0x00000010)
#define FUART_TX_FIFO_INT_MASK                 ((uint32_t)0x00000020)
#define FUART_RX_TIMEOUT_INT_MASK              ((uint32_t)0x00000040)
#define FUART_FRAMING_ERR_INT_MASK             ((uint32_t)0x00000080)
#define FUART_PARITY_ERR_INT_MASK              ((uint32_t)0x00000100)
#define FUART_BREAK_ERR_INT_MASK               ((uint32_t)0x00000200)
#define FUART_OVERRUN_ERR_INT_MASK             ((uint32_t)0x00000400)
#define FUART_ALL_INT_MASK                     ((uint32_t)0x000007F0)

#define IS_INT_MASK_SRC(param)                 (((param) == FUART_NONE_INT_MASK)|| \
                                                (((param) & FUART_ALL_INT_MASK)&& \
                                                (!((param) &(uint32_t) (~FUART_ALL_INT_MASK)))))

#define IS_FUART_DATA(param)                   ((param) <= (uint32_t)0x000000FF)


#define DUTY_EN_SET                          ((uint32_t)0x00000001U)
#define DUTY_EN_CLEAR                        ((uint32_t)0xFFFFFFFEU)

#define LOOPBACK_EN_SET                          ((uint32_t)0x00000080U)
#define LOOPBACK_EN_CLEAR                        ((uint32_t)0xFFFFFF7FU)

#define FUART_PERIOD_DETEC_1             ((uint32_t)0x00000010U)
#define FUART_PERIOD_DETEC_2             ((uint32_t)0x00000020U)
#define FUART_PERIOD_DETEC_3             ((uint32_t)0x00000030U)
#define FUART_PERIOD_DETEC_4             ((uint32_t)0x00000040U)
#define FUART_PERIOD_DETEC_5             ((uint32_t)0x00000050U)
#define FUART_PERIOD_DETEC_6             ((uint32_t)0x00000060U)
#define FUART_PERIOD_DETEC_7             ((uint32_t)0x00000070U)
#define IS_PERIOD_DETECTION(param)  (((param) == FUART_PERIOD_DETEC_1) || \
                                     ((param) == FUART_PERIOD_DETEC_2) || \
                                     ((param) == FUART_PERIOD_DETEC_3) || \
                                     ((param) == FUART_PERIOD_DETEC_4) || \
                                     ((param) == FUART_PERIOD_DETEC_5) || \
                                     ((param) == FUART_PERIOD_DETEC_6) || \
                                     ((param) == FUART_PERIOD_DETEC_7))

#define FUART_TXD50A    ((uint32_t)0x00000000U)
#define FUART_TXD50B    ((uint32_t)0x00000004U)
#define IS_TERMINAL_SELECTION(param)  (((param) == FUART_TXD50A) || \
                                       ((param) == FUART_TXD50B))

#define FUART_1_TERMINAL    ((uint32_t)0x00000000U)
#define FUART_2_TERMINAL    ((uint32_t)0x00000002U)
#define IS_TX_TERMINAL_MODE(param)  (((param) == FUART_1_TERMINAL) || \
                                     ((param) == FUART_2_TERMINAL))


/** @} */
/* End of group FUART_Exported_Constants */

/** @addtogroup FUART_Exported_Types
  * @{
  */
    typedef enum {
        FUART_STORAGE_EMPTY = 0U,
        FUART_STORAGE_NORMAL = 1U,
        FUART_STORAGE_INVALID = 2U,
        FUART_STORAGE_FULL = 3U
    } FUART_StorageStatus;

    typedef enum {
        FUART_RX = 0U,
        FUART_TX = 1U
    } FUART_Direction;

    typedef enum {
        FUART_NO_ERR = 0U,
        FUART_OVERRUN = 1U,
        FUART_PARITY_ERR = 2U,
        FUART_FRAMING_ERR = 3U,
        FUART_BREAK_ERR = 4U,
        FUART_ERRS = 5U
    } FUART_Err;

#define IS_FUART_DIRECTION(param)              (((param) == FUART_RX) || \
                                                ((param) == FUART_TX))

typedef union {
    uint32_t All;
    struct {
        uint32_t Reserved1:1;       /* bit 0 */
        uint32_t Reserved2:1;       /* bit 1 */
        uint32_t Reserved3:1;       /* bit 2 */
        uint32_t Reserved4:1;       /* bit 3 */
        uint32_t RxFIFO:1;          /* bit 4 */
        uint32_t TxFIFO:1;          /* bit 5 */
        uint32_t RxTimeout:1;       /* bit 6 */
        uint32_t FramingErr:1;      /* bit 7 */
        uint32_t ParityErr:1;       /* bit 8 */
        uint32_t BreakErr:1;        /* bit 9 */
        uint32_t OverrunErr:1;      /* bit 10 */
        uint32_t Reserved:21;       /* bit 11~31 */
    } Bit;
} FUART_INTStatus;


/** @} */
/* End of group FUART_Exported_Types */

/** @defgroup FUART_Exported_FunctionPrototypes
  * @{
  */

    void FUART_Enable(TSB_UART_TypeDef * FUARTx);
    void FUART_Disable(TSB_UART_TypeDef * FUARTx);
    uint32_t FUART_GetRxData(TSB_UART_TypeDef * FUARTx);
    void FUART_SetTxData(TSB_UART_TypeDef * FUARTx, uint32_t Data);
    FUART_Err FUART_GetErrStatus(TSB_UART_TypeDef * FUARTx);
    void FUART_ClearErrStatus(TSB_UART_TypeDef * FUARTx);
    WorkState FUART_GetBusyState(TSB_UART_TypeDef * FUARTx);
    FUART_StorageStatus FUART_GetStorageStatus(TSB_UART_TypeDef * FUARTx,
                                               FUART_Direction Direction);
    void FUART_Init(TSB_UART_TypeDef * FUARTx, FUART_InitTypeDef * InitStruct);
    void FUART_EnableFIFO(TSB_UART_TypeDef * FUARTx);
    void FUART_DisableFIFO(TSB_UART_TypeDef * FUARTx);
    void FUART_SetSendBreak(TSB_UART_TypeDef * FUARTx, FunctionalState NewState);
    void FUART_SetINTFIFOLevel(TSB_UART_TypeDef * FUARTx, uint32_t RxLevel, uint32_t TxLevel);
    void FUART_SetINTMask(TSB_UART_TypeDef * FUARTx, uint32_t IntMaskSrc);
    FUART_INTStatus FUART_GetINTMask(TSB_UART_TypeDef * FUARTx);
    FUART_INTStatus FUART_GetRawINTStatus(TSB_UART_TypeDef * FUARTx);
    FUART_INTStatus FUART_GetMaskedINTStatus(TSB_UART_TypeDef * FUARTx);
    void FUART_ClearINT(TSB_UART_TypeDef * FUARTx, FUART_INTStatus INTStatus);
    void FUART_DisableDuty(TSB_UART_TypeDef * FUARTx);
    void FUART_EnableDuty(TSB_UART_TypeDef * FUARTx);
    void FUART_EnableLoopBack(TSB_UART_TypeDef * FUARTx);
    void FUART_DisableLoopBack(TSB_UART_TypeDef * FUARTx);
    void FUART_SetPeriodDetection(TSB_UART_TypeDef * FUARTx, uint32_t PeriodDetection );
    void FUART_SetTxTerminalMode(TSB_UART_TypeDef * FUARTx, uint32_t TxTerminalMode);
    void FUART_SetStartBitTerminal(TSB_UART_TypeDef * FUARTx, uint32_t StartBitTerminal);

/** @} */
/* End of group FUART_Exported_FunctionPrototypes */

/** @} */
/* End of group FUART */

/** @} */
/* End of group TX03_Periph_Driver */
#endif                          /* defined(__TMPM383_FUART_H) */

#ifdef __cplusplus
}
#endif
#endif                          /* __TMPM383_FUART_H */
