/** 
 *******************************************************************************
 * @file    main.c
 * @brief   The application functions of DNF demo for the TOSHIBA
 *          'TMPM383' Device Series 
 * @version V0.100
 * @date    2015/06/03
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * (C)Copyright TOSHIBA ELECTRONIC DEVICES & STORAGE CORPORATION 2017 All rights reserved
 *******************************************************************************
 */

/* Includes ------------------------------------------------------------------*/
#include "main.h"
/* Private define ------------------------------------------------------------*/
//#define  CORRECT_PULSE 
#define  NOISE_PULSE 
/* Global variables ----------------------------------------------------------*/
volatile uint32_t Flag = 0U;
#if defined CORRECT_PULSE /* 7-8 clocks */
    uint32_t RG0Value = 0x00000008U;
    uint32_t RG1Value = 0x000000010U;
#elif defined NOISE_PULSE /* less than 7 clocks */
    uint32_t RG0Value = 0x00000006U;
    uint32_t RG1Value = 0x0000000CU;
#endif
/* Private functions ---------------------------------------------------------*/
/* Main function */
int main(void)
{
  volatile int i=0;
  
    /* Configure UART */
    hardware_init(UART_RETARGET);
      
    /* Configure 16-bit PPG */
    TMRB7_Config();
    /* Start PPG count operation */
    TMRB_SetRunState(TSB_TB7, TMRB_RUN);

    /* Configure GPIO to INT3 (PA0) */
    GPIO_SetInput(GPIO_PA, GPIO_BIT_0);
    GPIO_EnableFuncReg(GPIO_PA, GPIO_FUNC_REG_2, GPIO_BIT_0);
 
    /* fsys/4 clock output, 10 MHz */
    DNF_SetFilterClk(DNF_FILTER_CLK_FSYS_4);

    /* Enable INT3 noise filter circuit */
    DNF_SetInt3Filter(ENABLE);

    /* Set interrupt for DNF */
    __disable_irq();
    NVIC_ClearPendingIRQ(INT3_IRQn);
    NVIC_EnableIRQ(INT3_IRQn);
    __enable_irq();
    
    while(1U) {
#if defined CORRECT_PULSE
        if (Flag == 1U) {
            common_uart_disp("DNF processed with error !\r\n");
        } else {
            common_uart_disp("Correct pulse is detected !\r\n");
        }
#elif defined NOISE_PULSE
        if (Flag == 1U) {
            common_uart_disp("Noise pulse is detected !\r\n");
        } else {
            common_uart_disp("DNF processed with error !\r\n");
        }
#endif
    }
    
}

/**
  * @brief  Deal with the error parameter
  * @param  file: Pointer to the file where the error parameter locates
  * @param  line: Number of the line in which the error parameter locates
  * @retval None
  */
#ifdef DEBUG
void assert_failed(char *file, int32_t line)
{
    while (1) {
        __NOP();
    }
}
#endif

/*********************************** END OF FILE ******************************/
