/**
 *******************************************************************************
 * @file    main.c
 * @brief   The application functions of FUART_LoopBack demo for the
 *          TOSHIBA 'TMPM383' Device Series
 * @version V0.100
 * @date    2015/06/18
 *
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 *
 * (C)Copyright TOSHIBA ELECTRONIC DEVICES & STORAGE CORPORATION 2017 All rights reserved
 *******************************************************************************
 */

/* include file */
#include "main.h"

/* #define RUN_NONE_FLOW_CONTROL */

#define MAX_BUFSIZE  64U

int main(void)
{
    TestResult result = DIFF;
    FUART_StorageStatus FIFOStatus;
    uint32_t cntTx = 0U;
    uint32_t cntRx = 0U;
    uint8_t SW0_last = 0U;
    uint8_t SW0_this = 0U;

    uint32_t receive = 0U;      /* received data */
    uint32_t rxlast = 0U;       /* received data number after last reception */
    uint32_t rxthis = 0U;       /* received data number after this reception */
    uint32_t Rx_Buf[MAX_BUFSIZE] = { 0U };
    uint32_t Tx_Buf[MAX_BUFSIZE] = { 0U };

    uint32_t i = 0U;
    for (; i < MAX_BUFSIZE; i++) {
        Tx_Buf[i] = i;
    }

    LED_Init();
    SW_Init();
      
    FUART_GPIOConfig();         /* Configure GPIO for FUART0 */
    FUART_ChInit();             /* Initialize FUART0 */

    FUART_SetPeriodDetection(FUART0, FUART_PERIOD_DETEC_7 );
    FUART_SetTxTerminalMode(FUART0, FUART_1_TERMINAL);
    FUART_SetStartBitTerminal(FUART0, FUART_TXD50A);
    FUART_EnableDuty(FUART0);
    
    FUART_EnableFIFO(FUART0);
    FUART_SetINTFIFOLevel(FUART0, FUART_RX_FIFO_LEVEL_16, FUART_TX_FIFO_LEVEL_4);
    FUART_Enable(FUART0);
    

    SW0_this = SW_Get(SW0);
    while (1) {
        if (cntTx < MAX_BUFSIZE) {
            FIFOStatus = FUART_GetStorageStatus(FUART0, FUART_TX);
            if ((FIFOStatus == FUART_STORAGE_EMPTY) || (FIFOStatus == FUART_STORAGE_NORMAL)) {
                FUART_SetTxData(FUART0, Tx_Buf[cntTx]);
                cntTx++;
                if (64U == cntTx) {
                    LED_On(LED_ALL);    /* sending data is finished */
                }
            }
        }

        SW0_last = SW0_this;
        SW0_this = SW_Get(SW0);
        if (SW0_last != SW0_this) {     /* turn the switch SW0 */
            while (FUART_STORAGE_EMPTY != FUART_GetStorageStatus(FUART0, FUART_RX)) {
                receive = FUART_GetRxData(FUART0);
                Rx_Buf[cntRx] = receive;
                cntRx++;
            }

            rxlast = rxthis;
            rxthis = cntRx;

            if (rxlast != rxthis) {     /* there are some data that has been received  */
                LED_Off(LED_ALL);
                LED_On(LED2);
            } else {            /* receiving data is finished */
                result = Buffercompare(Tx_Buf, Rx_Buf, MAX_BUFSIZE);
                if (result == SAME) {
                    /* received data are same with transmitted data */
                    LED_Off(LED_ALL);
                    LED_On(LED1);
                    while (1) {
                    }
                } else {
                    /* received data are different with transmitted data */
                    LED_Off(LED_ALL);
                    LED_On(LED0);
                    while (1) {
                    }
                }
            }
        }
    }
}


#ifdef DEBUG
void assert_failed(char *file, int32_t line)
{
    while (1) {
        __NOP();
    }
}
#endif

/**
  * @brief  Compare Received data and Transmitted data
  * @param  Src : pointer to point source buffer
  * @param  Dst : pointer to point destination buffer
  * @param  Len : The length of data buffer
  * @retval SAME: received data are same with transmitted data
            DIFF: received data are different with transmitted data
  */
TestResult Buffercompare(const uint32_t * Src, const uint32_t * Dst, uint32_t Len)
{
    uint32_t tmp = 0U;
    TestResult result = SAME;

    for (tmp = 0U; tmp < Len; tmp++) {
        if (Src[tmp] != Dst[tmp]) {
            result = DIFF;
            break;
        } else {
        }
    }

    return result;
}

/**
  * @brief  Configure GPIO for Full UART pins, TX, RX, CTS, RTS
  * @param  None
  * @retval None
  */
void FUART_GPIOConfig(void)
{
     /* Configure port PC5 to be UT0TXD50B */
    GPIO_SetOutput(GPIO_PC, GPIO_BIT_5);
    GPIO_SetPullUp(GPIO_PC, GPIO_BIT_5, ENABLE);
    GPIO_SetPullDown(GPIO_PC, GPIO_BIT_5, DISABLE);
    GPIO_SetOpenDrain(GPIO_PC, GPIO_BIT_5, DISABLE);
    GPIO_EnableFuncReg(GPIO_PC, GPIO_FUNC_REG_5, GPIO_BIT_5);    
    
    /* Configure port PC6 to be UT0TXD50A */
    GPIO_SetOutput(GPIO_PC, GPIO_BIT_6); 
    GPIO_SetPullUp(GPIO_PC, GPIO_BIT_6, ENABLE);
    GPIO_SetPullDown(GPIO_PC, GPIO_BIT_6, DISABLE);
    GPIO_SetOpenDrain(GPIO_PC, GPIO_BIT_6, DISABLE);
    GPIO_EnableFuncReg(GPIO_PC, GPIO_FUNC_REG_5, GPIO_BIT_6);   

    /* Configure port PC7 to be UT0RXD50 */
    GPIO_SetInput(GPIO_PC, GPIO_BIT_7);
    GPIO_SetPullUp(GPIO_PC, GPIO_BIT_7, ENABLE);
    GPIO_SetPullDown(GPIO_PC, GPIO_BIT_7, DISABLE);
    GPIO_SetOpenDrain(GPIO_PC, GPIO_BIT_7, DISABLE);
    GPIO_EnableFuncReg(GPIO_PC, GPIO_FUNC_REG_5, GPIO_BIT_7);
}

/**
  * @brief  Initialize Full UART channel 0
  * @param  None
  * @retval None
  */
void FUART_ChInit(void)
{
    FUART_InitTypeDef myFUART;

    myFUART.BaudRate = 300U;
    myFUART.DataBits = FUART_DATA_BITS_8;
    myFUART.StopBits = FUART_STOP_BITS_1;
    myFUART.Parity = FUART_1_PARITY;
    myFUART.Mode = FUART_ENABLE_TX | FUART_ENABLE_RX;
    myFUART.FlowCtrl = FUART_NONE_FLOW_CTRL;

    FUART_Init(FUART0, &myFUART);
}
