/** 
 *******************************************************************************
 * @file    retarget.c
 * @brief   the application functions of UART_Retarget
 * @version V0.100
 * @date    2015/06/18
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * (C)Copyright TOSHIBA ELECTRONIC DEVICES & STORAGE CORPORATION 2017 All rights reserved
 *******************************************************************************
 */

/* Includes ------------------------------------------------------------------*/

#include "retarget.h"
/* External function prototypes ----------------------------------------------*/


extern uint8_t gSIOTxBuffer[BUFFER_SIZE];

extern volatile uint8_t gSIORdIndex;
extern volatile uint8_t gSIOWrIndex;
extern uint8_t fSIO_INT;
extern uint8_t fSIOTxOK;

extern uint8_t send_char(uint8_t ch);


/**
  * @brief  Retarget printf to uart.
  * @param  IAR:Character to be sent.KEIL:Character to be sent.
  * @retval Character to be sent
  */

#if defined ( __CC_ARM   )      /* RealView Compiler */
struct __FILE {
    int handle;                 /* Add whatever you need here */
};
FILE __stdout;
FILE __stdin;
int fputc(int ch, FILE * f)
#elif defined ( __ICCARM__ )    /*IAR Compiler */
int putchar(int ch)
#endif
{
    return (send_char(ch));
}

/**
  * @brief  Configure ReTarget Pin
  * @param  None
  * @retval None
  */
void Retarget_Configuration(void)
{
    /* Configure for SCxTXD pin */
    TSB_RETG->FR1 |= TXD_BIT ;
    TSB_RETG->CR |=  TXD_BIT ;

    /* Configure for SCxRXD pin */
    TSB_RETG->FR1 |= RXD_BIT;
    TSB_RETG->IE |= RXD_BIT;
}


/**
  * @brief  Initialize ReTarget Channel
  * @param  SCx: Select the UART channel.
  * @retval None
  */
void Retarget_ChInit(TSB_SC_TypeDef * SCx)
{
    UART_InitTypeDef myUART;

    /* configure SIOx for reception */
    UART_Enable(SCx);
    myUART.BaudRate = 115200U;  /* baud rate = 115200 */
    myUART.DataBits = UART_DATA_BITS_8; /* no handshake, 8-bit data, clock by baud rate generator */
    myUART.StopBits = UART_STOP_BITS_1; /* 1-bit stop, LSB,  W-buff enable */
    myUART.Parity = UART_NO_PARITY;
    myUART.Mode = UART_ENABLE_TX;
    myUART.FlowCtrl = UART_NONE_FLOW_CTRL;
    UART_Init(SCx, &myUART);
}

/**
  * @brief  Initialize Retarget.
  * @param  None
  * @retval None
  */

void Retarget_Init(void)
{
    Retarget_Configuration();
    Retarget_ChInit(UART_RETARGET);
    
    /* Enable retarget Channel TX interrupt */
    NVIC_EnableIRQ(INT_RETARGET_IRQn);
}


/**
  * @brief  Send character by SIOx
  * @param  Character to be sent
  * @retval Character to be sent
  */
uint8_t send_char(uint8_t ch)
{
    uint8_t tmp;

   do{
      tmp = gSIORdIndex;                /* set the read order for 2 volatile variable */ 
   } while ( tmp!=gSIOWrIndex );        /* wait for finishing sending */ 

    gSIOTxBuffer[gSIOWrIndex++] = ch;   /* fill TxBuffer */
    if (fSIO_INT == CLEAR) {    /* if SIO INT disable, enable it */
        fSIO_INT = SET;         /* set SIO INT flag */
        UART_SetTxData(UART_RETARGET, gSIOTxBuffer[gSIORdIndex++]);
        NVIC_EnableIRQ(INT_RETARGET_IRQn);
    }

    return ch;
}
