/**
 ******************************************************************************
 * @file    main.c
 * @brief   The main functions of SBI master demo for the
 *          TOSHIBA 'TMPM383' Device Series
 * @version V0.100
 * @date    2015/06/17
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * (C)Copyright TOSHIBA ELECTRONIC DEVICES & STORAGE CORPORATION 2017 All rights reserved
 ******************************************************************************
 */

#include "main.h"

SBI_InitI2CTypeDef myI2C;
uint32_t gI2CWCnt;
uint32_t gI2CTxDataLen;
char gI2CTxData[16] = { 0 };

uint32_t gSBIMode;

/**
  * @brief  Get state of SW7 to check key value is or not same  
  * @param  None
  * @retval None
  */
uint8_t getkey(uint8_t sw)
{
    uint32_t i = 20000;
    uint8_t keyflag;
    uint8_t oneflag, twoflag;
    oneflag = SW_Get(sw);
    while (i--);
    twoflag = SW_Get(sw);
    if (oneflag != twoflag) {
        keyflag = 1;
    } else { 
    keyflag = 0;
    }
    return keyflag;
}

/**
  * @brief  The main routine of SBI demo I2C
  * @param  None
  * @retval None
  */
int main(void)
{   
    SBI_I2CState i2c_state;
    SW_Init();
  
    /* Initialize IO for SBI */
    SBI_IO_Configuration();
    /* Initialize SBI channel */
    myI2C.I2CSelfAddr = SELF_ADDR;
    myI2C.I2CDataLen = SBI_I2C_DATA_LEN_8;
    myI2C.I2CACKState = ENABLE;
    myI2C.I2CClkDiv = SBI_I2C_CLK_DIV_328;
    SBI_Enable(TSB_SBI0);
    SBI_SWReset(TSB_SBI0);
    SBI_InitI2C(TSB_SBI0, &myI2C);
    NVIC_EnableIRQ(INTSBI0_IRQn);
  
    /* Initialize variables for SBI */
    gI2CTxDataLen = 0U;
    gI2CWCnt = 0U;
    gSBIMode = MODE_SBI_I2C_IDLE;
    
    while (1) {
        switch (gSBIMode) {
            /* SW7 input check */
        case MODE_SBI_I2C_IDLE:
            if (getkey(SW7)) {
              while (SW_Get(SW7)); 
              gSBIMode = MODE_SBI_I2C_INITIAL;
            } else {
                /* Do nothing */
            }
            break;
            /* Initialize TRx buffer and Tx length */
        case MODE_SBI_I2C_INITIAL:
            gI2CTxDataLen = 7U;
            gI2CTxData[0] = gI2CTxDataLen;
            gI2CTxData[1] = 'T';
            gI2CTxData[2] = 'O';
            gI2CTxData[3] = 'S';
            gI2CTxData[4] = 'H';
            gI2CTxData[5] = 'I';
            gI2CTxData[6] = 'B';
            gI2CTxData[7] = 'A';
            
            gI2CWCnt = 0U;
            gSBIMode = MODE_SBI_I2C_START;
            break;
            /* Check I2C bus state and start TRx */
        case MODE_SBI_I2C_START:
            i2c_state = SBI_GetI2CState(TSB_SBI0);
            if (!i2c_state.Bit.BusState) {
              gSBIMode = MODE_SBI_I2C_TRX;
              SBI_SetSendData(TSB_SBI0, SLAVE_ADDR | SBI_I2C_SEND);
              SBI_GenerateI2CStart(TSB_SBI0);
            } else {
                /* Do nothing */
            }
            break;
        case MODE_SBI_I2C_TRX:  
            if (gI2CWCnt > 7) {
                 gI2CWCnt = 0U;
                 gSBIMode = MODE_SBI_I2C_IDLE;
            } else {
                 /* Do nothing */
            } 
            break;
        default:
            gI2CTxDataLen = 0U;
            gI2CWCnt = 0U;
            gSBIMode = MODE_SBI_I2C_IDLE;
            break;
        }
    }
}

/**
  * @brief  Configure the GPIO for SBI0
  * @param  None
  * @retval None
  */
void SBI_IO_Configuration(void)
{
    GPIO_EnableFuncReg(GPIO_PC, GPIO_FUNC_REG_3, GPIO_BIT_0 | GPIO_BIT_1);
    GPIO_SetOutputEnableReg(GPIO_PC, GPIO_BIT_0 | GPIO_BIT_1, ENABLE);
    GPIO_SetInputEnableReg(GPIO_PC, GPIO_BIT_0 | GPIO_BIT_1, ENABLE);
    GPIO_SetOpenDrain(GPIO_PC, GPIO_BIT_0 | GPIO_BIT_1, ENABLE);
    /* Pull up for SDA&SCL */
    GPIO_SetPullUp(GPIO_PC, GPIO_BIT_0 | GPIO_BIT_1, ENABLE);
}

#ifdef DEBUG
/**
  * @brief  Deal with the error parameter
  * @param  file: Pointer to the file where the error parameter locates
  * @param  line: Number of the line in which the error parameter locates
  * @retval None
  */
void assert_failed(char *file, int32_t line)
{
    while (1) {
        __NOP();
    }
}
#endif
