/**
 *******************************************************************************
 * @file    main.c
 * @brief   the application functions of TMRB_TIMER demo for the TOSHIBA
 *          'TMPM383' Device Series 
 * @version V0.100
 * @date    2014/06/23
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * (C)Copyright TOSHIBA ELECTRONIC DEVICES & STORAGE CORPORATION 2017 All rights reserved
 *******************************************************************************
 */

/* Includes ------------------------------------------------------------------*/
#include "main.h"

/**
  * @brief  The main function of TMRB_TIMER demo
  * @param  None
  * @retval None
  */
int main(void)
{
    TMRB_InitTypeDef m_tmrb;
    
    LED_Init();                  /* LED initialize */
    LED_On(LED_ALL);               /* Turn on LED_ALL */

    m_tmrb.Mode = TMRB_INTERVAL_TIMER;  /* internal timer */
    m_tmrb.ClkDiv = TMRB_CLK_DIV_8;     /* 1/8PhiT0 */            
    m_tmrb.TrailingTiming = TMRB_1MS;   /* periodic time is 1ms */
    m_tmrb.UpCntCtrl = TMRB_AUTO_CLEAR;
    m_tmrb.LeadingTiming = TMRB_1MS;    /* periodic time is 1ms */

    TMRB_Enable(TSB_TB0);                       /* enable the TMRB0 */
    TMRB_Init(TSB_TB0, &m_tmrb);                /* initial the TMRB0 */
    NVIC_EnableIRQ(INTTB00_IRQn);               /* enable INTTB0 interrupt */
    TMRB_SetRunState(TSB_TB0, TMRB_RUN);        /* run TMRB0*/

    while (1) {
        /* Do nothing */
    }
}

/**
  * @brief  Deal with the error parameter
  * @param  file: Pointer to the file where the error parameter locates
  * @param  line: Number of the line in which the error parameter locates
  * @retval None
  */
#ifdef DEBUG
void assert_failed(char *file, int32_t line)
{
    while (1) {
        __NOP();
    }
}
#endif

