/**
 ******************************************************************************
 * @file     led.c
 * @brief    LED driver for the TOSHIBA 'TMPM383' Device Series
 * @version  V0.100
 * @date     2015/05/20
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * (C)Copyright TOSHIBA ELECTRONIC DEVICES & STORAGE CORPORATION 2017 All rights reserved
 ******************************************************************************
 */

/* Includes ------------------------------------------------------------------*/
#include "led.h"

/**
  * @brief  Initialize LED ports.
  *   LED0~3 connect with PA0~3.
  * @param  None
  * @retval None
  */
void LED_Init(void)
{
    /* Set PA0 ~ PA3 as output and turn off LED0 ~ LED3 */
    GPIO_SetPullDown(GPIO_PA, GPIO_BIT_0 | GPIO_BIT_1 | GPIO_BIT_2 | GPIO_BIT_3, ENABLE);
    GPIO_SetOutput(GPIO_PA, GPIO_BIT_0 | GPIO_BIT_1 | GPIO_BIT_2 | GPIO_BIT_3);
}

/**
  * @brief  Turn on input LED.
  * @param  led: LED number
  *   This parameter can be one of the following values:
  *   LED0, LED1, LED2, LED3 or LED_ALL.
  * @retval None
  */
void LED_On(uint8_t led)
{
    uint8_t tmp;
    tmp = GPIO_ReadData(GPIO_PA);
    tmp |= led;
    GPIO_WriteData(GPIO_PA, tmp);
}

/**
  * @brief  Turn off input LED.
  * @param  led: LED number
  *   This parameter can be one of the following values:
  *   LED0, LED1, LED2, LED3 or LED_ALL.
  * @retval None
  */
void LED_Off(uint8_t led)
{
    uint8_t tmp;
    tmp = GPIO_ReadData(GPIO_PA);
    tmp &= (uint8_t) (~led);
    GPIO_WriteData(GPIO_PA, tmp);
}
