/**
 ******************************************************************************
 * @file     sw.c
 * @brief    SW driver for the TOSHIBA 'TMPM383' Device Series
 * @version  V0.100
 * @date     2015/05/20
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * (C)Copyright TOSHIBA ELECTRONIC DEVICES & STORAGE CORPORATION 2017 All rights reserved
 ******************************************************************************
 */

/* Includes ------------------------------------------------------------------*/
#include "sw.h"

/**
  * @brief  Initialize the GPIO to SW.
  *   SW0/4 connect with PH4.
  *   SW1/5 connect with PH5.
  *   SW2/6 connect with PH6.
  *   SW3/7 connect with PH7.
  * @param  None
  * @retval None
  */
void SW_Init(void)
{
    GPIO_SetPullDown(GPIO_PH, GPIO_BIT_4 | GPIO_BIT_5 | GPIO_BIT_6 | GPIO_BIT_7, ENABLE);
    GPIO_SetInput(GPIO_PH,  GPIO_BIT_4 | GPIO_BIT_5 | GPIO_BIT_6 | GPIO_BIT_7);
}

/**
  * @brief  Get SW Value.
  * @param  sw: SW number
  *   This parameter can be from SW0 ~ SW7.
  * @retval SW value.
  */
uint8_t SW_Get(uint8_t sw)
{
    uint8_t tmp = 0U;
    switch (sw) {
    case SW0:
    case SW4:
        if (GPIO_ReadDataBit(GPIO_PH, GPIO_BIT_4) == 1U) {
            tmp = 1U;
        } else {
            /*Do nothing */
        }
        break;
    case SW1:
    case SW5:
        if (GPIO_ReadDataBit(GPIO_PH, GPIO_BIT_5) == 1U) {
            tmp = 1U;
        } else {
            /*Do nothing */
        }
        break;
    case SW2:
    case SW6:
        if (GPIO_ReadDataBit(GPIO_PH, GPIO_BIT_6) == 1U) {
            tmp = 1U;
        } else {
            /*Do nothing */
        }
        break;
    case SW3:
    case SW7:
        if (GPIO_ReadDataBit(GPIO_PH, GPIO_BIT_7) == 1U) {
            tmp = 1U;
        } else {
            /*Do nothing */
        }
        break;
    default:
        break;
    }
    
    return tmp;
}
