/**
 *******************************************************************************
 * @file    main.c
 * @brief   The application functions of WDT demo for the
 *          TOSHIBA 'TMPM383' Device Series 
 * @version V0.100
 * @date    2015/06/09
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * (C)Copyright TOSHIBA ELECTRONIC DEVICES & STORAGE CORPORATION 2017 All rights reserved
 *******************************************************************************
 */

#include "tmpm383_wdt.h"
#include "led.h"
extern uint8_t fIntNMI;
/* #define DEMO2 */

/* Delay(time) */
void Delay(uint32_t time)
{
    volatile uint32_t i = 0U;
    for (i = 0U; i < (time * 800U); ++i){
        /* Do nothing */
    }
}

/* main() */
int main(void)
{
    WDT_InitTypeDef WDT_InitStruct;
 
    /* Detect time is set to 2^25/fsys */ 
    WDT_InitStruct.DetectTime = WDT_DETECT_TIME_EXP_25;
 
    /* Interrupt will be generated when timer overflow */
    WDT_InitStruct.OverflowOutput = WDT_NMIINT;

    /* Initialize LED */
    LED_Init();

    /* Turn off all LED */
    LED_Off(LED_ALL);

    /* Initialize WDT */
    WDT_Init(&WDT_InitStruct);

    /* Enable WDT */
    WDT_Enable();

    while (1) {
        if (fIntNMI == 1U) {
            fIntNMI = 0U;

            /* Blink LED1 */
            LED_On(LED1);
            Delay(500U);
            LED_Off(LED1);
            Delay(500U);

            /* Disable WDT */
            WDT_Disable();
        } else {
            /* Do nothing */
        }
#ifdef DEMO2
        Delay(500U);

        /* Clear WDT counter before timer overflow */
        WDT_WriteClearCode();
        
        /* Blink LED0 */
        LED_On(LED0);
        Delay(500U);
        LED_Off(LED0);
#endif
    }
}

#ifdef DEBUG
void assert_failed(char *file, int32_t line)
{
    while (1) {
        __NOP();
    }
}
#endif
